#ifndef QT_FEATURES_WaylandCompositor_src_compositor_qtwaylandcompositor_config_p_h_H
#define QT_FEATURES_WaylandCompositor_src_compositor_qtwaylandcompositor_config_p_h_H

#define QT_FEATURE_wayland_server 1

#define QT_FEATURE_wayland_dmabuf_client_buffer -1

#define QT_FEATURE_wayland_layer_integration_vsp2 -1


#endif // QT_FEATURES_WaylandCompositor_src_compositor_qtwaylandcompositor_config_p_h_H
